oblique.split.writer(
coefficients,
impurity,
child.left.T.F,
superclass.composition)coefficients, the coefficients of this split and superclass.targets, a record of the targets of the classification problem that lead to this ideal split."" for oblique splits and a variable name for axis-parallel splits.